==> console-plugin-service-3.1-b22-sources.jar: org/glassfish/admingui/plugin/IndexItemInjector.java <==

package org.glassfish.admingui.plugin;

import java.util.ArrayList;
import java.util.List;
import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.config.ConfigInjector;
import org.jvnet.hk2.config.Dom;
import org.jvnet.hk2.config.InjectionTarget;

@Service(name = "indexitem", metadata = "@text=required,@text=datatype:java.lang.String,@text=leaf,@target=required,@target=datatype:java.lang.String,@target=leaf,target=org.glassfish.admingui.plugin.IndexItem,<indexitem>=collection:org.glassfish.admingui.plugin.IndexItem")
@InjectionTarget(org.glassfish.admingui.plugin.IndexItem.class)
public class IndexItemInjector
    extends ConfigInjector<org.glassfish.admingui.plugin.IndexItem>
{


    public void inject(Dom dom, org.glassfish.admingui.plugin.IndexItem target) {
        element_setIndexItems(dom, target);
        attribute_setTarget(dom, target);
        attribute_setText(dom, target);
    }

    public void injectAttribute(Dom dom, String name, org.glassfish.admingui.plugin.IndexItem target) {
        if ("target".equals(name)) {
            attribute_setTarget(dom, target);
        }
        if ("text".equals(name)) {
            attribute_setText(dom, target);
        }
    }

    public void injectElement(Dom dom, String name, org.glassfish.admingui.plugin.IndexItem target) {
        if ("indexitem".equals(name)) {
            element_setIndexItems(dom, target);
        }
    }

    public void element_setIndexItems(Dom dom, org.glassfish.admingui.plugin.IndexItem target) {
        List<Dom> v1 = dom.nodeElements("indexitem");
        if (v1 == null) {
            return ;
        }
        List v2 = new ArrayList<org.glassfish.admingui.plugin.IndexItem>(v1 .size());
        for (Dom v3 : v1) {
            v2 .add(((org.glassfish.admingui.plugin.IndexItem) v3 .get()));
        }
        target.setIndexItems(v2);
    }

    public void attribute_setTarget(Dom dom, org.glassfish.admingui.plugin.IndexItem target) {
        String v1 = dom.attribute("target");
        target.setTarget(v1);
    }

    public void attribute_setText(Dom dom, org.glassfish.admingui.plugin.IndexItem target) {
        String v1 = dom.attribute("text");
        target.setText(v1);
    }

}

==> console-plugin-service-3.1.1-b01-sources.jar: org/glassfish/admingui/plugin/IndexItemInjector.java <==

package org.glassfish.admingui.plugin;

import java.util.ArrayList;
import java.util.List;
import org.jvnet.hk2.annotations.Service;
import org.jvnet.hk2.config.ConfigInjector;
import org.jvnet.hk2.config.Dom;
import org.jvnet.hk2.config.InjectionTarget;

@Service(name = "indexitem", metadata = "target=org.glassfish.admingui.plugin.IndexItem,<indexitem>=collection:org.glassfish.admingui.plugin.IndexItem,@target=required,@target=datatype:java.lang.String,@target=leaf,@text=required,@text=datatype:java.lang.String,@text=leaf")
@InjectionTarget(org.glassfish.admingui.plugin.IndexItem.class)
public class IndexItemInjector
    extends ConfigInjector<org.glassfish.admingui.plugin.IndexItem>
{


    public void inject(Dom dom, org.glassfish.admingui.plugin.IndexItem target) {
        element_setIndexItems(dom, target);
        attribute_setTarget(dom, target);
        attribute_setText(dom, target);
    }

    public void injectAttribute(Dom dom, String name, org.glassfish.admingui.plugin.IndexItem target) {
        if ("target".equals(name)) {
            attribute_setTarget(dom, target);
        }
        if ("text".equals(name)) {
            attribute_setText(dom, target);
        }
    }

    public void injectElement(Dom dom, String name, org.glassfish.admingui.plugin.IndexItem target) {
        if ("indexitem".equals(name)) {
            element_setIndexItems(dom, target);
        }
    }

    public void element_setIndexItems(Dom dom, org.glassfish.admingui.plugin.IndexItem target) {
        List<Dom> v1 = dom.nodeElements("indexitem");
        if (v1 == null) {
            return ;
        }
        List v2 = new ArrayList<org.glassfish.admingui.plugin.IndexItem>(v1 .size());
        for (Dom v3 : v1) {
            v2 .add(((org.glassfish.admingui.plugin.IndexItem) v3 .get()));
        }
        target.setIndexItems(v2);
    }

    public void attribute_setTarget(Dom dom, org.glassfish.admingui.plugin.IndexItem target) {
        String v1 = dom.attribute("target");
        target.setTarget(v1);
    }

    public void attribute_setText(Dom dom, org.glassfish.admingui.plugin.IndexItem target) {
        String v1 = dom.attribute("text");
        target.setText(v1);
    }

}
